Authors & Contributors
----------------------

In no particular order:

- Brad Montgomery `<mailto:brad@bradmontgomery.net>`_
- Jonatan Heyman `<https://github.com/heyman>`_
- Daniel Lindsley `<https://github.com/toastdriven>`_
- Charles Vallantin Dulac `<https://github.com/charles-vdulac>`_
- Reza Mohammadi `<https://github.com/remohammadi>`_
- mvillarejo `<https://github.com/mvillarejo>`_
- vlinhart `<https://github.com/vlinhart>`_
- Dr. Stefan Schimanski `<https://github.com/sttts>`_
- Seamus Mac Conaonaigh `<https://github.com/smaccona>`_
- Phoebe Bright `<https://github.com/phoebebright>`_
- Stephan Pötschner `<https://github.com/stephanpoetschner>`_
- Elias Laitinen `<https://github.com/eliasla>`_
- Derek Marsh `<https://github.com/dmarsh19>`_
